==> haskell-http-client-0.5.6.1-3-i686.pkg.tar.xz: usr/share/haskell/register/haskell-http-client.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: http-client
version: 0.5.6.1
id: http-client-0.5.6.1-BpluvowJzclKWa0VheNANV
key: http-client-0.5.6.1-BpluvowJzclKWa0VheNANV
license: MIT
maintainer: michael@snoyman.com
homepage: https://github.com/snoyberg/http-client
synopsis: An HTTP client engine
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/http-client>.
category: Network
author: Michael Snoyman
exposed: True
exposed-modules:
    Network.HTTP.Client Network.HTTP.Client.MultipartFormData
    Network.HTTP.Client.Internal
hidden-modules: Network.HTTP.Client.Body
                Network.HTTP.Client.Connection Network.HTTP.Client.Cookies
                Network.HTTP.Client.Core Network.HTTP.Client.Headers
                Network.HTTP.Client.Manager Network.HTTP.Client.Request
                Network.HTTP.Client.Response Network.HTTP.Client.Types
                Network.HTTP.Client.Util Network.PublicSuffixList.Lookup
                Network.PublicSuffixList.Types Network.PublicSuffixList.Serialize
                Network.PublicSuffixList.DataStructure
abi: 13a96ca47372ee62a6e0ba0998b1a15d
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/http-client-0.5.6.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/http-client-0.5.6.1
data-dir: /usr/share/i386-linux-ghc-8.0.1/http-client-0.5.6.1
hs-libraries: HShttp-client-0.5.6.1-BpluvowJzclKWa0VheNANV
depends:
    array-0.5.1.1 base-4.9.0.0
    base64-bytestring-1.0.0.1-In9M41tLtcS9QYt3QpGpNY
    blaze-builder-0.4.0.2-2VmGHau0mFrAjwd4n28WWF bytestring-0.10.8.1
    case-insensitive-1.2.0.8-19yABacCVqnEmCaYKTVngi containers-0.5.7.1
    cookie-0.4.2.1-DnnDAS5t2oj6QKbT9Eh839 deepseq-1.4.2.0
    exceptions-0.8.3-5cAKIsqc1DD7jaNW3zLxAN filepath-1.4.1.0
    ghc-prim-0.5.0.0 http-types-0.9.1-DAWlwwLyGeDDnRhY9ftEgi
    mime-types-0.1.0.7-1TVT7pakOnO6kciNbLYizr
    network-2.6.3.1-G4Up1CPKbp7DeFsnywOnGG
    network-uri-2.6.1.0-8yR4gjnzE4eDGhJR7PHfVJ
    random-1.1-54KmMHXjttlERYcr1mvsAe
    streaming-commons-0.1.17-6k51SJxMSKy6BYhtadRCnX
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ time-1.6.0.1
    transformers-0.5.2.0
haddock-interfaces: /usr/share/doc/haskell-http-client/html/http-client.haddock
haddock-html: /usr/share/doc/haskell-http-client/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-http-client-0.5.6.1-4-i686.pkg.tar.xz: usr/share/haskell/register/haskell-http-client.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: http-client
version: 0.5.6.1
id: http-client-0.5.6.1-wVCkiPnh0GHIyvDsvtfzo
key: http-client-0.5.6.1-wVCkiPnh0GHIyvDsvtfzo
license: MIT
maintainer: michael@snoyman.com
homepage: https://github.com/snoyberg/http-client
synopsis: An HTTP client engine
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/http-client>.
category: Network
author: Michael Snoyman
exposed: True
exposed-modules:
    Network.HTTP.Client Network.HTTP.Client.MultipartFormData
    Network.HTTP.Client.Internal
hidden-modules: Network.HTTP.Client.Body
                Network.HTTP.Client.Connection Network.HTTP.Client.Cookies
                Network.HTTP.Client.Core Network.HTTP.Client.Headers
                Network.HTTP.Client.Manager Network.HTTP.Client.Request
                Network.HTTP.Client.Response Network.HTTP.Client.Types
                Network.HTTP.Client.Util Network.PublicSuffixList.Lookup
                Network.PublicSuffixList.Types Network.PublicSuffixList.Serialize
                Network.PublicSuffixList.DataStructure
abi: cc69f7c16183a3a28b9ca59f45b514be
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/http-client-0.5.6.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/http-client-0.5.6.1
data-dir: /usr/share/i386-linux-ghc-8.0.1/http-client-0.5.6.1
hs-libraries: HShttp-client-0.5.6.1-wVCkiPnh0GHIyvDsvtfzo
depends:
    array-0.5.1.1 base-4.9.0.0
    base64-bytestring-1.0.0.1-In9M41tLtcS9QYt3QpGpNY
    blaze-builder-0.4.0.2-2VmGHau0mFrAjwd4n28WWF bytestring-0.10.8.1
    case-insensitive-1.2.0.9-HR7ngNnTOX66jDpe7AgOeu containers-0.5.7.1
    cookie-0.4.2.1-DnnDAS5t2oj6QKbT9Eh839 deepseq-1.4.2.0
    exceptions-0.8.3-5cAKIsqc1DD7jaNW3zLxAN filepath-1.4.1.0
    ghc-prim-0.5.0.0 http-types-0.9.1-E37jBtYKNpTKS6SyGsLwFU
    mime-types-0.1.0.7-1TVT7pakOnO6kciNbLYizr
    network-2.6.3.1-G4Up1CPKbp7DeFsnywOnGG
    network-uri-2.6.1.0-8yR4gjnzE4eDGhJR7PHfVJ
    random-1.1-54KmMHXjttlERYcr1mvsAe
    streaming-commons-0.1.17-6k51SJxMSKy6BYhtadRCnX
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ time-1.6.0.1
    transformers-0.5.2.0
haddock-interfaces: /usr/share/doc/haskell-http-client/html/http-client.haddock
haddock-html: /usr/share/doc/haskell-http-client/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
